<?php 
/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! function_exists( 'skt_moviemaker_setup' ) ) : 
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 */
function skt_moviemaker_setup() {
	$GLOBALS['content_width'] = apply_filters( 'skt_moviemaker_content_width', 640 );
	load_theme_textdomain( 'skt-moviemaker', get_stylesheet_directory_uri() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support('woocommerce');
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'title-tag' );
	add_post_type_support( 'page', 'excerpt' );
	add_theme_support( 'wc-product-gallery-zoom' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );
	add_theme_support( 'custom-logo', array(
		'height'      => 77,
		'width'       => 204,
		'flex-height' => true,
	) );	
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary Menu', 'skt-moviemaker' )				
	) );
	add_theme_support( 'custom-background', array(
		'default-color' => '000000'
	) );
} 
endif; // skt_moviemaker_setup
add_action( 'after_setup_theme', 'skt_moviemaker_setup' );

add_action( 'wp_enqueue_scripts', 'skt_moviemaker_enqueue_styles' );
function skt_moviemaker_enqueue_styles() {
  wp_enqueue_style( 'skt-moviemaker-parent-style', get_template_directory_uri() . '/style.css' ); 
} 

add_action( 'wp_enqueue_scripts', 'skt_moviemaker_child_styles', 99);
function skt_moviemaker_child_styles() {
  wp_enqueue_style( 'skt-moviemaker-child-style', get_stylesheet_directory_uri()."/css/responsive.css" );
} 

function skt_moviemaker_admin_style() {
  wp_enqueue_script('skt-moviemaker-admin-script', get_stylesheet_directory_uri()."/js/skt-moviemaker-admin-script.js");
}
add_action('admin_enqueue_scripts', 'skt_moviemaker_admin_style');

function skt_moviemaker_admin_about_page_css_enqueue($hook) {
   if ( 'appearance_page_skt_moviemaker_guide' != $hook ) {
        return;
    }
    wp_enqueue_style( 'skt-moviemaker-about-page-style', get_stylesheet_directory_uri() . '/css/skt-moviemaker-about-page-style.css' );
}
add_action( 'admin_enqueue_scripts', 'skt_moviemaker_admin_about_page_css_enqueue' );

/**
 * Show notice on theme activation
 */
if ( is_admin() && isset($_GET['activated'] ) && $pagenow == "themes.php" ) {
	add_action( 'admin_notices', 'skt_moviemaker_activation_notice' );
}
function skt_moviemaker_activation_notice(){
    ?>
    <div class="notice notice-info is-dismissible"> 
        <div class="skt-videography-notice-container">
        	<div class="skt-videography-notice-img"><img src="<?php echo esc_url( SKT_MOVIEMAKER_SKTTHEMES_THEME_URI . 'images/icon-skt-templates.png' ); ?>" alt="<?php echo esc_attr('SKT Templates');?>" ></div>
            <div class="skt-videography-notice-content">
            <div class="skt-videography-notice-heading"><?php echo esc_html__('Thank you for installing SKT Moviemaker!', 'skt-moviemaker'); ?></div>
            <p class="largefont"><?php echo esc_html__('SKT Barbecue comes with 150+ ready to use Elementor templates. Install the SKT Templates plugin to get started.', 'skt-moviemaker'); ?></p>
            </div>
            <div class="skt-videography-clear"></div>
        </div>
    </div>
    <?php
}

if ( ! function_exists( 'skt_moviemaker_the_custom_logo' ) ) :
/**
 * Displays the optional custom logo.
 *
 * Does nothing if the custom logo is not available.
 *
 */
function skt_moviemaker_the_custom_logo() {
	if ( function_exists( 'the_custom_logo' ) ) {
		the_custom_logo();
	}
}
endif;

function skt_moviemaker_widgets_init() { 	
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'skt-moviemaker' ),
		'description'   => esc_html__( 'Appears on sidebar', 'skt-moviemaker' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',		
		'before_title'  => '<h3 class="widget-title titleborder"><span>',
		'after_title'   => '</span></h3>',
		'after_widget'  => '</aside>',
	) ); 	
	
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Column 1', 'skt-moviemaker' ),
		'description'   => esc_html__( 'Appears on page footer', 'skt-moviemaker' ),
		'id'            => 'fc-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',		
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
		'after_widget'  => '</aside>',
	) );
	
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Column 2', 'skt-moviemaker' ),
		'description'   => esc_html__( 'Appears on page footer', 'skt-moviemaker' ),
		'id'            => 'fc-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',		
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
		'after_widget'  => '</aside>',
	) );
	
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Column 3', 'skt-moviemaker' ),
		'description'   => esc_html__( 'Appears on page footer', 'skt-moviemaker' ),
		'id'            => 'fc-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',		
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
		'after_widget'  => '</aside>',
	) );		
		
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Column 4', 'skt-moviemaker' ),
		'description'   => esc_html__( 'Appears on page footer', 'skt-moviemaker' ),
		'id'            => 'fc-4',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',		
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
		'after_widget'  => '</aside>',
	) );	
	
}
add_action( 'widgets_init', 'skt_moviemaker_widgets_init' );

define('SKT_MOVIEMAKER_SKTTHEMES_URL','https://www.sktthemes.org');
define('SKT_MOVIEMAKER_SKTTHEMES_PRO_THEME_URL','https://www.sktthemes.org/shop/film-production-wordpress-theme/');
define('SKT_MOVIEMAKER_SKTTHEMES_FREE_THEME_URL','https://www.sktthemes.org/shop/free-movie-studio-wordpress-theme/');
define('SKT_MOVIEMAKER_SKTTHEMES_THEME_DOC','https://www.sktthemesdemo.net/documentation/skt-videography-doc/');
define('SKT_MOVIEMAKER_SKTTHEMES_LIVE_DEMO','https://sktperfectdemo.com/themepack/moviemaker/');
define('SKT_MOVIEMAKER_SKTTHEMES_THEMES','https://www.sktthemes.org/themes');
define('SKT_MOVIEMAKER_SKTTHEMES_THEME_URI', trailingslashit( esc_url( get_template_directory_uri() ) ) );

function skt_moviemaker_remove_parent_function(){	 
	remove_action( 'admin_notices', 'skt_videography_activation_notice');
	remove_action( 'admin_menu', 'skt_videography_abouttheme');
	remove_action( 'customize_register', 'skt_videography_customize_register');
	remove_action( 'wp_enqueue_scripts', 'skt_videography_custom_css');
}
add_action( 'init', 'skt_moviemaker_remove_parent_function' );

function skt_moviemaker_remove_parent_theme_stuff() {
    remove_action( 'after_setup_theme', 'skt_videography_setup' );
}
add_action( 'after_setup_theme', 'skt_moviemaker_remove_parent_theme_stuff', 0 );

require_once get_stylesheet_directory() . '/inc/about-themes.php';
require_once get_stylesheet_directory() . '/inc/customizer.php';