<?php
/**
 * SKT Moviemaker Theme Customizer
 *
 * @package SKT Moviemaker
 */
function skt_moviemaker_custom_header_setup() {
	add_theme_support( 'custom-header', apply_filters( 'skt_moviemaker_custom_header_args', array(
		'default-text-color'     => '949494',
		'width'                  => 1600,
		'height'                 => 230,
		'wp-head-callback'       => 'skt_moviemaker_header_style',
 		'default-text-color' => false,
 		'header-text' => false,
	) ) );
}
add_action( 'after_setup_theme', 'skt_moviemaker_custom_header_setup' );
if ( ! function_exists( 'skt_moviemaker_header_style' ) ) :
/**
 * Styles the header image and text displayed on the blog
 *
 * @see skt_moviemaker_custom_header_setup().
 */
function skt_moviemaker_header_style() {
	?>
	<style type="text/css">
	<?php
		//Check if user has defined any header image.
		if ( get_header_image() ) :
	?>
		.header {
			background: url(<?php echo esc_url(get_header_image()); ?>) no-repeat;
			background-position: center top;
			background-size:cover;
		}
	<?php endif; ?>	
	</style>
	<?php
}
endif; // skt_moviemaker_header_style 
/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */ 
/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function skt_moviemaker_customize_register( $wp_customize ) {
	//Add a class for titles
    class skt_moviemaker_Info extends WP_Customize_Control {
        public $type = 'info';
        public $label = '';
        public function render_content() {
        ?>
			<h3 style="text-decoration: underline; color: #DA4141; text-transform: uppercase;"><?php echo esc_html( $this->label ); ?></h3>
        <?php
        }
    }
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->add_setting('color_scheme',array(
			'default'	=> '#e2a750',
			'sanitize_callback'	=> 'sanitize_hex_color'
	));
	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'color_scheme',array(
			'label' => esc_html__('Color Scheme','skt-moviemaker'),			
			 'description'	=> esc_html__('More color options in PRO Version','skt-moviemaker'),	
			'section' => 'colors',
			'settings' => 'color_scheme'
		))
	);
	
	$wp_customize->add_section('page_header_settings',array(
			'title'	=> esc_html__('Page Header Settings','skt-moviemaker'),					
			'priority'		=> null
	));
	
    $wp_customize->add_setting( 'page_header_image', array(
        'default' => get_theme_file_uri('images/title_bar_bg.jpg'),
        'sanitize_callback' => 'esc_url_raw'
    ));
 
    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'page_header_image_control', array(
        'label'	=> esc_html__('Page Header Banner','skt-moviemaker'),
        'section' => 'page_header_settings',
        'settings' => 'page_header_image',
        'button_labels' => array(// All These labels are optional
                    'select' => 'Select Logo',
                    'remove' => 'Remove Logo',
                    'change' => 'Change Logo',
                    )
    )));

	$wp_customize->add_setting('hide_header_image',array(
			'sanitize_callback' => 'skt_moviemaker_sanitize_checkbox',
			'default' => false,
	));	 
	$wp_customize->add_control( 'hide_header_image', array(
    	   'section'   => 'page_header_settings',    	 
		   'label'	=> esc_html__('Checked to hide banner','skt-moviemaker'),
    	   'type'      => 'checkbox'
     ));
	 
	$wp_customize->add_section('post_header_settings',array(
			'title'	=> esc_html__('Post Header Settings','skt-moviemaker'),					
			'priority'		=> null
	));
	
    $wp_customize->add_setting( 'post_header_image', array(
        'default' => get_theme_file_uri('images/title_bar_bg.jpg'),
        'sanitize_callback' => 'esc_url_raw'
    ));
 
    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'post_header_image_control', array(
        'label'	=> esc_html__('Post Header Banner','skt-moviemaker'),
        'section' => 'post_header_settings',
        'settings' => 'post_header_image',
        'button_labels' => array( // All These labels are optional
					'select' => esc_attr__( 'Select Logo', 'skt-moviemaker' ),
					'remove' => esc_attr__( 'Remove Logo', 'skt-moviemaker' ),
					'change' => esc_attr__( 'Change Logo', 'skt-moviemaker' ),
    	)
    )));

	$wp_customize->add_setting('hide_post_header_image',array(
			'sanitize_callback' => 'skt_moviemaker_sanitize_checkbox',
			'default' => false,
	));	 
	$wp_customize->add_control( 'hide_post_header_image', array(
    	   'section'   => 'post_header_settings',    	 
		   'label'	=> esc_html__('Checked to hide banner','skt-moviemaker'),
    	   'type'      => 'checkbox'
     )); 	 

	$wp_customize->add_section('footer_bar',array(
			'title'	=> esc_html__('Footer Info Box','skt-moviemaker'),					
			'priority'		=> null
	));
	
	
    $wp_customize->add_setting( 'footer_logo_image', array(
        'default' => '', 
        'sanitize_callback' => 'esc_url_raw'
    ));
 
    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'footer_logo_image_control', array(
        'label'	=> esc_html__('Footer Logo','skt-moviemaker'),
        'section' => 'footer_bar',
        'settings' => 'footer_logo_image',
        'button_labels' => array( // All These labels are optional
					'select' => esc_attr__( 'Select Logo', 'skt-moviemaker' ),
					'remove' => esc_attr__( 'Remove Logo', 'skt-moviemaker' ),
					'change' => esc_attr__( 'Change Logo', 'skt-moviemaker' ),
    	)
    )));
	
	$wp_customize->add_setting('footer_logo_url',array(
			'default'	=> null,
			'sanitize_callback'	=> 'esc_url_raw'	
	));
	
	$wp_customize->add_control('footer_logo_url',array(
			'label'	=> esc_html__('Footer Logo Link','skt-moviemaker'),
			'section'	=> 'footer_bar',
			'setting'	=> 'footer_logo_url'
	));		

	$wp_customize->add_setting('fb_link',array(
			'default'	=> null,
			'sanitize_callback'	=> 'esc_url_raw'	
	));
	
	$wp_customize->add_control('fb_link',array(
			'label'	=> esc_html__('Add Facebook Link','skt-moviemaker'),
			'section'	=> 'footer_bar',
			'setting'	=> 'fb_link'
	));	
	$wp_customize->add_setting('twitt_link',array(
			'default'	=> null,
			'sanitize_callback'	=> 'esc_url_raw'
	));
	
	$wp_customize->add_control('twitt_link',array(
			'label'	=> esc_html__('Add Twitter Link','skt-moviemaker'),
			'section'	=> 'footer_bar',
			'setting'	=> 'twitt_link'
	));
	$wp_customize->add_setting('linked_link',array(
			'default'	=> null,
			'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('linked_link',array(
			'label'	=> esc_html__('Add Linkedin Link','skt-moviemaker'),
			'section'	=> 'footer_bar',
			'setting'	=> 'linked_link'
	));
	
	$wp_customize->add_setting('youtube_link',array(
			'default'	=> null,
			'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('youtube_link',array(
			'label'	=> esc_html__('Add Youtube Link','skt-moviemaker'),
			'section'	=> 'footer_bar',
			'setting'	=> 'youtube_link'
	));	
	
	$wp_customize->add_setting('insta_link',array(
			'default'	=> null,
			'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('insta_link',array(
			'label'	=> esc_html__('Add Instagram Link','skt-moviemaker'),
			'section'	=> 'footer_bar',
			'setting'	=> 'insta_link'
	));		

	// Hide Footer Info Box
	$wp_customize->add_setting('hide_footer_bar',array(
			'sanitize_callback' => 'skt_moviemaker_sanitize_checkbox',
			'default' => true,
	));	 
	$wp_customize->add_control( 'hide_footer_bar', array(
    	   'section'   => 'footer_bar',    	 
		   'label'	=> esc_html__('Uncheck To Show This Section','skt-moviemaker'),
    	   'type'      => 'checkbox'
     )); 	
	 // Hide Footer Info Box		 
}
add_action( 'customize_register', 'skt_moviemaker_customize_register' );
//Integer
function skt_moviemaker_sanitize_integer( $input ) {
    if( is_numeric( $input ) ) {
        return intval( $input );
    }
}
function skt_moviemaker_sanitize_checkbox( $checked ) {
	// Boolean check.
	return ( ( isset( $checked ) && true == $checked ) ? true : false );
}

//setting inline css.
function skt_moviemaker_custom_css() {
    wp_enqueue_style(
        'skt-moviemaker-custom-style',
        get_stylesheet_directory_uri() . '/css/skt-moviemaker-custom-style.css' 
    );
        $color = esc_html(get_theme_mod( 'color_scheme' )); //E.g. #e64d43
        $custom_css = "
					#sidebar ul li a:hover,
					.footerarea a:hover,
					.cols-3 ul li.current_page_item a,								
					.left a:hover,
					.blog_lists h4 a:hover,
					.recent-post h6 a:hover,
					.recent-post a:hover,
					.design-by a,
					.postmeta a:hover,
					.tagcloud a,
					.blocksbox:hover h3,
					.cols-3 span,
					.section1top-block-area h2 span,
					.rdmore a,
					.woocommerce ul.products li.product:hover .woocommerce-loop-product__title,
					.sec3-block-button2,
					.designboxbg:hover .designbox-content h3,
					.site-navigation ul li a:hover, .site-navigation ul li.current_page_item a, .site-navigation ul li.menu-item-has-children.hover, .site-navigation ul li.current-menu-parent a.parent
					{ 
						 color: {$color} !important;
					}
					.pagination .nav-links span.current, .pagination .nav-links a:hover,
					#commentform input#submit:hover,
					.wpcf7 input[type='submit'],
					a.ReadMore,
					input.search-submit,
					.recent-post .morebtn:hover, 
					.read-more-btn,
					.designs-thumb,
					.hometwo-block-button,
					.nivo-controlNav a.active,
					.aboutmore,
					.view-all-btn a:hover,
					.social-icons a:hover
					{ 
					   background-color: {$color} !important;
					}
					.woocommerce ul.products li.product:hover,
					.nivo-controlNav a
					{
					   border-color: {$color} !important;
					}
					.titleborder span:after{border-bottom-color: {$color} !important;}					
					
				";
        wp_add_inline_style( 'skt-moviemaker-custom-style', $custom_css );
}
add_action( 'wp_enqueue_scripts', 'skt_moviemaker_custom_css' );